SQLAlchemy 0.5 Documentation - module sqlalchemy.databases.access

# SQLAlchemy 0.5 Documentation

Multiple Pages | One Page
Version: 0.5.0rc3 Last Updated: 11/07/08 13:55:35

### module sqlalchemy.databases.access

### class AcBinary(Binary)

def get_col_spec(self)
back to section top

### class AcBoolean(Boolean)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class AcChar(CHAR)

def get_col_spec(self)
back to section top

### class AcDate(Date)

def __init__(self, *a, **kw)

Construct a new `AcDate`.

def get_col_spec(self)
back to section top

### class AcDateTime(DateTime)

def __init__(self, *a, **kw)

Construct a new `AcDateTime`.

def get_col_spec(self)
back to section top

### class AcFloat(Float)

def bind_processor(self, dialect)

By converting to string, we can use Decimal types round-trip.

def get_col_spec(self)
back to section top

### class AcInteger(Integer)

def get_col_spec(self)
back to section top

### class AcNumeric(Numeric)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class AcSmallInteger(SmallInteger)

def get_col_spec(self)
back to section top

### class AcString(String)

def get_col_spec(self)
back to section top

### class AcText(Text)

def get_col_spec(self)
back to section top

### class AcTimeStamp(TIMESTAMP)

def get_col_spec(self)
back to section top

### class AcTinyInteger(Integer)

def get_col_spec(self)
back to section top

### class AcUnicode(Unicode)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class AccessCompiler(DefaultCompiler)

def binary_operator_string(self, binary)

Access uses "mod" instead of "%"

def for_update_clause(self, select)

FOR UPDATE is not supported by Access; silently ignore

def label_select_column(self, select, column, asfrom)
def limit_clause(self, select)

Limit in access is after the select keyword

def visit_function(self, func)

Access function names differ from the ANSI SQL names; rewrite common ones

def visit_select_precolumns(self, select)

Access puts TOP, it's version of LIMIT here

def visit_table(self, table, asfrom=False, **kwargs)
back to section top

### class AccessDefaultRunner(DefaultRunner)

back to section top

### class AccessDialect(DefaultDialect)

def __init__(self, **params)

Construct a new `AccessDialect`.

def create_connect_args(self, url)
def create_execution_context(self, *args, **kwargs)
def dbapi(cls)
def do_execute(self, cursor, statement, params, **kwargs)
def has_table(self, connection, tablename, schema=None)
def last_inserted_ids(self)
def reflecttable(self, connection, table, include_columns)
def table_names(self, connection, schema)
def type_descriptor(self, typeobj)
back to section top

### class AccessExecutionContext(DefaultExecutionContext)

def post_exec(self)

If we inserted into a row with a COUNTER column, fetch the ID

back to section top

### class AccessIdentifierPreparer(IdentifierPreparer)

def __init__(self, dialect)

Construct a new `AccessIdentifierPreparer`.

back to section top

### class AccessSchemaDropper(SchemaDropper)

def visit_index(self, index)
back to section top

### class AccessSchemaGenerator(SchemaGenerator)

def get_column_specification(self, column, **kwargs)
back to section top